==> qmmp-0.12.14.tar.bz2: qmmp-0.12.14/src/plugins/Output/qtmultimedia/translations/qtmultimedia_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>OutputQtMultimediaFactory</name>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="33"/>
        <source>Qt Multimedia Plugin</source>
        <translation>Wtyczka Qt Multimedia</translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="58"/>
        <source>About Qt Multimedia Output Plugin</source>
        <translation>O wtyczce wyjściowej Qt Multimedia</translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="59"/>
        <source>Qmmp Qt Multimedia Output Plugin</source>
        <translation>Wtyczka wyjściowa Qt Multimedia dla Qmmp</translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="60"/>
        <source>Written by: Ivan Ponomarev &lt;ivantrue@gmail.com&gt;</source>
        <translation>Napisana przez: Ivan Ponomarev &lt;ivantrue@gmail.com&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Qt Multimedia Plugin Settings</source>
        <translation>Ustawienia wtyczki Qt Multimedia</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="46"/>
        <source>Device:</source>
        <translation>Urządzenie:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Default</source>
        <translation>Domyślne</translation>
    </message>
</context>
</TS>

==> qmmp_1.1.10.orig.tar.bz2: qmmp-1.1.10/src/plugins/Output/qtmultimedia/translations/qtmultimedia_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>OutputQtMultimediaFactory</name>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="33"/>
        <source>Qt Multimedia Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="58"/>
        <source>About Qt Multimedia Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="59"/>
        <source>Qmmp Qt Multimedia Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputqtmultimediafactory.cpp" line="60"/>
        <source>Written by: Ivan Ponomarev &lt;ivantrue@gmail.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Qt Multimedia Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="46"/>
        <source>Device:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
